//
//  GameZodiacViewController.m
//  Memory Game
//
//  Created by Giorgio Minissale on 11/07/14.
//  Copyright (c) 2014 DevCo s.r.l. All rights reserved.
//

#import "GameZodiacViewController.h"

@interface GameZodiacViewController ()
//Declare Private Properties
//add a blank tile image and an image of the tile that is flipped over
@property UIImage *blankTileImage;
@property UIImage *backTileImage;

//Array of tile images
@property NSMutableArray *tiles;
//Array of shuffled tile IDs
@property NSMutableArray *shuffledTiles;
//How many times did the player get a match
@property NSInteger matchCounter;
//How many times did the player guess
@property NSInteger guessCounter;
//The ID of the first flipped tile
@property NSInteger tileFlipped;
//The first button object that was clicked
@property UIButton *tile1;
//The second button object that was clicked
@property UIButton *tile2;

//Instance Methods
- (void)shuffleTiles;
- (void)resetTiles;
- (void) winner;
@end

@implementation GameZodiacViewController{
    NSString *levelType;
    NSTimer *bestime;
    int seconds;
}
//Local Variables
static bool isDisabled = false;
static bool isMatch = false;

- (void)viewDidLoad
{
    [super viewDidLoad];
    [[RevMobAds session] showBanner];
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    levelType = [defaults objectForKey:@"TYPE"];
    
    if ([levelType isEqualToString:@"TIME"]) {
        bestime = [NSTimer scheduledTimerWithTimeInterval:1
                                                   target:self
                                                 selector:@selector(timerController)
                                                 userInfo:nil
                                                  repeats:YES];
    }
    
    //This is where we will initialize our properties once this scene has loaded
    //Assign images to the blank and back image properties
    
    
    if(UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        //device is an iPad.
        self.backTileImage = [UIImage imageNamed:@"BackCarta2_100.png"];
        self.blankTileImage = [UIImage imageNamed:@"blank.png"];
    }
    else
    {
        self.backTileImage = [UIImage imageNamed:@"back2.png"];
        self.blankTileImage = [UIImage imageNamed:@"blank.png"];
    }
    
    //Set the tile flipped variable less than zero so we know that a tile has not been clicked yet
    self.tileFlipped = -1;
    
    //set our guesses and matches to zero
    self.matchCounter = 0;
    self.guessCounter = 0;
    //Show the score at the top of our screen in the tile clicked
    [self.gameScoreLabel setTextColor:[UIColor whiteColor]];
    [self.gameScoreLabel setFont:[UIFont fontWithName:kFontName size:19]];
    
    
    [self.gameTimeLabel setTextColor:[UIColor whiteColor]];
    [self.gameTimeLabel setFont:[UIFont fontWithName:kFontName size:19]];
    
    if ([levelType isEqualToString:@"MOVES"])
        self.gameScoreLabel.text = [NSString stringWithFormat:@"Matches: %ld Guesses: %ld", (long)self.matchCounter, (long)self.guessCounter];
    
    
    if(UI_USER_INTERFACE_IDIOM() == UIUserInterfaceIdiomPad) {
        self.tiles = [[NSMutableArray alloc]initWithObjects:
                      [UIImage imageNamed:@"zodiac_01_ipad.png"],
                      [UIImage imageNamed:@"zodiac_01_ipad.png"],
                      [UIImage imageNamed:@"zodiac_02_ipad.png"],
                      [UIImage imageNamed:@"zodiac_02_ipad.png"],
                      [UIImage imageNamed:@"zodiac_03_ipad.png"],
                      [UIImage imageNamed:@"zodiac_03_ipad.png"],
                      [UIImage imageNamed:@"zodiac_04_ipad.png"],
                      [UIImage imageNamed:@"zodiac_04_ipad.png"],
                      [UIImage imageNamed:@"zodiac_05_ipad.png"],
                      [UIImage imageNamed:@"zodiac_05_ipad.png"],
                      [UIImage imageNamed:@"zodiac_06_ipad.png"],
                      [UIImage imageNamed:@"zodiac_06_ipad.png"],
                      [UIImage imageNamed:@"zodiac_07_ipad.png"],
                      [UIImage imageNamed:@"zodiac_07_ipad.png"],
                      [UIImage imageNamed:@"zodiac_08_ipad.png"],
                      [UIImage imageNamed:@"zodiac_08_ipad.png"],
                      [UIImage imageNamed:@"zodiac_09_ipad.png"],
                      [UIImage imageNamed:@"zodiac_09_ipad.png"],
                      [UIImage imageNamed:@"zodiac_10_ipad.png"],
                      [UIImage imageNamed:@"zodiac_10_ipad.png"],
                      [UIImage imageNamed:@"zodiac_11_ipad.png"],
                      [UIImage imageNamed:@"zodiac_11_ipad.png"],
                      [UIImage imageNamed:@"zodiac_12_ipad.png"],
                      [UIImage imageNamed:@"zodiac_12_ipad.png"],
                      nil];
    }
    else
    {
        self.tiles = [[NSMutableArray alloc]initWithObjects:
                      [UIImage imageNamed:@"zodiac_01.png"],
                      [UIImage imageNamed:@"zodiac_01.png"],
                      [UIImage imageNamed:@"zodiac_02.png"],
                      [UIImage imageNamed:@"zodiac_02.png"],
                      [UIImage imageNamed:@"zodiac_03.png"],
                      [UIImage imageNamed:@"zodiac_03.png"],
                      [UIImage imageNamed:@"zodiac_04.png"],
                      [UIImage imageNamed:@"zodiac_04.png"],
                      [UIImage imageNamed:@"zodiac_05.png"],
                      [UIImage imageNamed:@"zodiac_05.png"],
                      [UIImage imageNamed:@"zodiac_06.png"],
                      [UIImage imageNamed:@"zodiac_06.png"],
                      [UIImage imageNamed:@"zodiac_07.png"],
                      [UIImage imageNamed:@"zodiac_07.png"],
                      [UIImage imageNamed:@"zodiac_08.png"],
                      [UIImage imageNamed:@"zodiac_08.png"],
                      [UIImage imageNamed:@"zodiac_09.png"],
                      [UIImage imageNamed:@"zodiac_09.png"],
                      [UIImage imageNamed:@"zodiac_10.png"],
                      [UIImage imageNamed:@"zodiac_10.png"],
                      [UIImage imageNamed:@"zodiac_11.png"],
                      [UIImage imageNamed:@"zodiac_11.png"],
                      [UIImage imageNamed:@"zodiac_12.png"],
                      [UIImage imageNamed:@"zodiac_12.png"],
                      nil];
    }
    
    [self shuffleTiles];
}

#pragma mark Timer
// TIMER METHODS

- (void)timerController {
    seconds++;
    self.gameTimeLabel.text = [NSString stringWithFormat:@"Time: %d s",seconds];
}

- (void)shuffleTiles
{
    int tileCount = (int) [self.tiles count];
    
    for (int tileID = 0; tileID < (tileCount/2); tileID++)
    {
        [self.shuffledTiles addObject:[NSNumber numberWithInt:tileID]];
        [self.shuffledTiles addObject:[NSNumber numberWithInt:tileID]];
    }
    
    for (NSUInteger i = 0; i < tileCount; ++i) {
        NSInteger nElements = tileCount - i;
        NSInteger n = (arc4random() % nElements) + i;
        [self.shuffledTiles exchangeObjectAtIndex:i withObjectAtIndex:n];
        [self.tiles exchangeObjectAtIndex:i withObjectAtIndex:n];
    }
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

-(IBAction)tileClicked:(id)sender
{
    if(isDisabled == true)
        return;
    int senderID = (int)[sender tag];
    
    if(self.tileFlipped >= 0 && senderID != self.tileFlipped)
    {
        self.tile2 = sender;
        
        UIImage *lastImage = [self.tiles objectAtIndex:self.tileFlipped];
        UIImage *tileImage = [self.tiles objectAtIndex:senderID];
        
        [sender setImage: tileImage forState:UIControlStateNormal];
        self.guessCounter++;
        if(tileImage == lastImage)
        {
            [self.tile1 setEnabled:false];
            [self.tile2 setEnabled:false];
            self.matchCounter++;
            isMatch = true;
        }
        isDisabled = true;
        //set up a timer to flip the tiles over after 1 sec.
        [NSTimer scheduledTimerWithTimeInterval:1.0
                                         target:self
                                       selector:@selector(resetTiles)
                                       userInfo:nil
                                        repeats:NO];
        self.tileFlipped = -1;
    }
    else
    {
        
        self.tileFlipped = senderID;
        self.tile1 = sender;
        UIImage *tileImage = [self.tiles objectAtIndex:senderID];
        [sender setImage: tileImage forState:UIControlStateNormal];
    }
    if ([levelType isEqualToString:@"MOVES"])
        self.gameScoreLabel.text = [NSString stringWithFormat:@"Matches: %ld Guesses: %ld", (long)self.matchCounter, (long)self.guessCounter];
}

- (void)resetTiles
{
    if(isMatch)
    {
        [self.tile1 setImage: self.blankTileImage forState:UIControlStateNormal];
        [self.tile2 setImage: self.blankTileImage forState:UIControlStateNormal];
    }
    else
    {
        [self.tile1 setImage: self.backTileImage forState:UIControlStateNormal];
        [self.tile2 setImage: self.backTileImage forState:UIControlStateNormal];
    }
    isDisabled = false;
    isMatch = false;

    if(self.matchCounter == (self.tiles.count/2))
        [self winner];
}

- (void) winner
{
    [bestime invalidate];
    NSUserDefaults *defaults = [NSUserDefaults standardUserDefaults];
    int highScore = (int) [defaults integerForKey:@"highScore_zodiac"];
    int besttimeEver = (int)[defaults integerForKey:@"bestime_zodiac"];
    
    if ([levelType isEqualToString:@"MOVES"])
    {
        if ((highScore == 0) && (self.guessCounter > 0))
        {
            [defaults setObject:[NSNumber numberWithInt:(int)self.guessCounter] forKey:@"highScore_zodiac"];
            self.gameScoreLabel.text = [NSString stringWithFormat:@"New best score! Guesses: %ld", (long)self.guessCounter];
            [[GameKitHelper sharedGameKitHelper] reportScore:(int)self.guessCounter forLeaderboardID:kLeaderboardZodiacMoves];
        }
        else if (highScore > self.guessCounter)
        {
            [defaults setObject:[NSNumber numberWithInt:(int)self.guessCounter] forKey:@"highScore_zodiac"];
            self.gameScoreLabel.text = [NSString stringWithFormat:@"New best score! Guesses: %ld", (long)self.guessCounter];
            [[GameKitHelper sharedGameKitHelper] reportScore:(int)self.guessCounter forLeaderboardID:kLeaderboardZodiacMoves];
        }
        else
            self.gameScoreLabel.text = [NSString stringWithFormat:@"Game over. Guesses: %ld", (long)self.guessCounter];
    }
    else
    {
        if ((besttimeEver == 0) && (seconds > 0))
        {
            [defaults setObject:[NSNumber numberWithInt:seconds] forKey:@"bestime_zodiac"];
            [[GameKitHelper sharedGameKitHelper]reportScore:seconds forLeaderboardID:kLeaderboardZodiacTime];
        }
        else if (besttimeEver > seconds) {
            // New record!
            [defaults setObject:[NSNumber numberWithInt:seconds] forKey:@"bestime_zodiac"];
            [[GameKitHelper sharedGameKitHelper]reportScore:seconds forLeaderboardID:kLeaderboardZodiacTime];
        }
        else
            self.gameScoreLabel.text = [NSString stringWithFormat:@"Game over. Seconds: %d", seconds];
    }
}

-(void) viewWillDisappear:(BOOL)animated
{
    [super viewWillDisappear:animated];
}

@end